#ifndef EFL_ORIENTATION_IMPL_HH
#define EFL_ORIENTATION_IMPL_HH

#include "efl_orientation.eo.hh"

namespace efl { 
inline ::efl::eolian::return_traits<Efl_Orient>::type Orientation::orientation_get() const
{
   Efl_Orient __return_value =  ::efl_orientation_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Efl_Orient>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Orientation::orientation_set( ::efl::eolian::in_traits<Efl_Orient>::type dir) const
{
    ::efl_orientation_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Efl_Orient,  ::efl::eolian::in_traits<Efl_Orient>::type>(dir));
}
inline ::efl::eolian::return_traits<Efl_Flip>::type Orientation::flip_get() const
{
   Efl_Flip __return_value =  ::efl_orientation_flip_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Efl_Flip>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Orientation::flip_set( ::efl::eolian::in_traits<Efl_Flip>::type flip) const
{
    ::efl_orientation_flip_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Efl_Flip,  ::efl::eolian::in_traits<Efl_Flip>::type>(flip));
}
} 
namespace eo_cxx {
namespace efl { 
inline ::efl::eolian::return_traits<Efl_Orient>::type Orientation::orientation_get() const
{
   Efl_Orient __return_value =  ::efl_orientation_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Efl_Orient>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Orientation::orientation_set( ::efl::eolian::in_traits<Efl_Orient>::type dir) const
{
    ::efl_orientation_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Efl_Orient,  ::efl::eolian::in_traits<Efl_Orient>::type>(dir));
}
inline ::efl::eolian::return_traits<Efl_Flip>::type Orientation::flip_get() const
{
   Efl_Flip __return_value =  ::efl_orientation_flip_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Efl_Flip>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Orientation::flip_set( ::efl::eolian::in_traits<Efl_Flip>::type flip) const
{
    ::efl_orientation_flip_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Efl_Flip,  ::efl::eolian::in_traits<Efl_Flip>::type>(flip));
}
inline efl::Orientation::operator ::efl::Orientation() const { return *static_cast< ::efl::Orientation const*>(static_cast<void const*>(this)); }
inline efl::Orientation::operator ::efl::Orientation&() { return *static_cast< ::efl::Orientation*>(static_cast<void*>(this)); }
inline efl::Orientation::operator ::efl::Orientation const&() const { return *static_cast< ::efl::Orientation const*>(static_cast<void const*>(this)); }
} }
#endif
